<!--
This file is automatically generated by tfds.scripts.documentation.document_datasets
and all modifications will be erased, please edit the
original document_datasets.py file.
-->
# Datasets

Note: The datasets documented here are from `HEAD` and so not all are available
in the current `tensorflow-datasets` package. They are all accessible in our
nightly package `tfds-nightly`.

---

## Usage

See our [getting-started guide](https://www.tensorflow.org/datasets/overview)
for a quick introduction.

```python
for ex in tfds.load('cifar10', split='train'):
  ...
```

## All Datasets

{toc}

---
